(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    106043,       2373]
NotebookOptionsPosition[    104525,       2327]
NotebookOutlinePosition[    104868,       2342]
CellTagsIndexPosition[    104825,       2339]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
     "**", "**", "**", "**", "**"}], "******)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"Stackelberg", " ", "equilibrium", " ", "with", " ", "regret"}], 
   " ", "*****)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
     "**", "**", "**", "**", "**"}], "******)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", "Initialization", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
     "**", "**", "**", "**", "**"}], "*****)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", "nB", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", "nD", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", "pD", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", "pB", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", "GammaD", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", "GammaB", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", "lambdaD", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", "lambdaB", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", "hd", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", "hb", "]"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"nD", "=", "5"}], ";"}], 
   RowBox[{"(*", 
    RowBox[{"number", " ", "of", " ", "DGDs"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"nB", "=", "7"}], ";"}], 
   RowBox[{"(*", 
    RowBox[{"number", " ", "of", " ", "BGDs"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"n", "=", "128"}], ";"}], 
   RowBox[{"(*", 
    RowBox[{"processing", " ", "gain"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"m", "=", "100"}], ";"}], 
   RowBox[{"(*", 
    RowBox[{"block", " ", "length"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g", "=", "128"}], ";"}], 
   RowBox[{"(*", 
    RowBox[{"Processing", " ", "gain"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"sigma", "=", 
     RowBox[{"Sqrt", "[", 
      RowBox[{"10", "^", 
       RowBox[{"(", 
        RowBox[{"-", "15"}], ")"}]}], "]"}]}], ";"}], 
   RowBox[{"(*", "noise", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pmax", "=", "1"}], ";", 
    RowBox[{"(*", 
     RowBox[{"max", " ", "power"}], "*)"}], "\[IndentingNewLine]", 
    RowBox[{"wf", "=", "1"}], ";", 
    RowBox[{"(*", 
     RowBox[{"weight", " ", "factor", " ", "coefficient"}], "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{"Rs", "=", "200000"}], ";", 
    RowBox[{"(*", 
     RowBox[{
     "max", " ", "Smart", " ", "Meter", " ", "data", " ", "rate", " ", 
      "Kbps"}], "*)"}], "\[IndentingNewLine]", 
    RowBox[{"R", "=", "17000"}], ";", 
    RowBox[{"(*", 
     RowBox[{
     "BGD", " ", "DGD", " ", "transmission", " ", "rate", " ", "Kbps"}], 
     "*)"}], "\[IndentingNewLine]", 
    RowBox[{"Rb", "=", 
     RowBox[{"Rd", "=", "R"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"hd", "=", 
     RowBox[{"Array", "[", 
      RowBox[{"0", ",", "nD"}], "]"}]}], ";", 
    RowBox[{"(*", 
     RowBox[{"*", "path", " ", "gain", " ", "of", " ", "DGDs"}], "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{"hb", "=", 
     RowBox[{"Array", "[", 
      RowBox[{"0", ",", "nB"}], "]"}]}], ";", 
    RowBox[{"(*", 
     RowBox[{"path", " ", "gain", " ", "of", " ", "BGDs"}], "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{"GammaD", "=", 
     RowBox[{"Array", "[", 
      RowBox[{"0", ",", "nD"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"GammaB", "=", 
     RowBox[{"Array", "[", 
      RowBox[{"0", ",", "nB"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pD", "=", 
     RowBox[{"Array", "[", 
      RowBox[{"0", ",", "nD"}], "]"}]}], ";", " ", 
    RowBox[{"(*", 
     RowBox[{"strategy", " ", "of", " ", "DGDs"}], "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{"pB", "=", 
     RowBox[{"Array", "[", 
      RowBox[{"0", ",", "nB"}], "]"}]}], ";", 
    RowBox[{"(*", 
     RowBox[{"strategy", " ", "of", " ", "BGDs"}], "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{"gammaD", "=", 
     RowBox[{"Array", "[", 
      RowBox[{"0", ",", "nD"}], "]"}]}], ";", 
    RowBox[{"(*", 
     RowBox[{"SINR", " ", "DGD"}], "*)"}], "\[IndentingNewLine]", 
    RowBox[{"gammaB", "=", 
     RowBox[{"Array", "[", 
      RowBox[{"0", ",", "nB"}], "]"}]}], ";", 
    RowBox[{"(*", 
     RowBox[{"SINR", " ", "BGD"}], "*)"}], "\[IndentingNewLine]", 
    RowBox[{"lambdaD", "=", 
     RowBox[{"Array", "[", 
      RowBox[{"0", ",", "nD"}], "]"}]}], ";", 
    RowBox[{"(*", 
     RowBox[{"incoming", " ", "data", " ", "rate", " ", "DGD"}], "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{"lambdaB", "=", 
     RowBox[{"Array", "[", 
      RowBox[{"0", ",", "nB"}], "]"}]}], ";", 
    RowBox[{"(*", 
     RowBox[{"incoming", " ", "data", " ", "rate", " ", "BGD"}], "*)"}], 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"eta", "=", "1"}], ";", 
    RowBox[{"(*", "reliability", "*)"}], "\[IndentingNewLine]", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"i", "=", "1"}], ",", 
      RowBox[{"i", "<", 
       RowBox[{"nB", "+", "1"}]}], ",", 
      RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"pB", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "=", "0.4"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"gammaB", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "=", "0"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"lambdaB", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "=", 
        RowBox[{"5000", "*", "i"}]}], ";"}]}], "\[IndentingNewLine]", "]"}], 
    ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"For", "[", 
    RowBox[{
     RowBox[{"i", "=", "1"}], ",", 
     RowBox[{"i", "<", 
      RowBox[{"nD", "+", "1"}]}], ",", 
     RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"pD", "[", 
        RowBox[{"[", "i", "]"}], "]"}], "=", "0.3"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"gammaD", "[", 
        RowBox[{"[", "i", "]"}], "]"}], "=", "0"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"lambdaD", "[", 
        RowBox[{"[", "i", "]"}], "]"}], "=", "8000"}], ";"}]}], 
    "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Path", " ", "gain"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"i", "=", "1"}], ",", 
      RowBox[{"i", "<", 
       RowBox[{"nD", "+", "1"}]}], ",", 
      RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"hd", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "=", 
        RowBox[{"10", "^", 
         RowBox[{"(", 
          RowBox[{"-", "13"}], ")"}]}]}], ";"}]}], "\[IndentingNewLine]", 
     "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"For", "[", 
    RowBox[{
     RowBox[{"i", "=", "1"}], ",", 
     RowBox[{"i", "<", 
      RowBox[{"nB", "+", "1"}]}], ",", 
     RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"hb", "[", 
        RowBox[{"[", "i", "]"}], "]"}], "=", 
       RowBox[{
        RowBox[{"10", "^", 
         RowBox[{"(", 
          RowBox[{"-", "13"}], ")"}]}], "/", "2"}]}], ";"}]}], 
    "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**", "**"}], "******)"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"**", "**", "**", "**", "**", "  ", "End"}], " ", 
     "Initialization"}], " ", "***********)"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**", "**"}], "*****)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", 
     "**", "**", "**", "**"}], "******)"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"DGD", " ", "SINR", " ", "function"}], ",", " ", 
     RowBox[{"calculate", " ", 
      RowBox[{"d_k", "'"}], "s", " ", "SINR", " ", "given", " ", "k", " ", 
      "and", " ", "vector", " ", "PB"}], ",", " ", "PD"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SINRD", "[", 
      RowBox[{
      "p_", ",", "k_", ",", "PB_", ",", "PD_", ",", "hb_", ",", "hd_", ",", 
       "nB_", ",", "nD_"}], "]"}], ":=", 
     RowBox[{"(", "\[IndentingNewLine]", 
      RowBox[{"sdk", "=", 
       RowBox[{"p", "*", 
        RowBox[{
         RowBox[{"hd", "[", 
          RowBox[{"[", "k", "]"}], "]"}], "/", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"sigma", "^", "2"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Sum", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"PD", "[", 
                  RowBox[{"[", "ii", "]"}], "]"}], "*", 
                 RowBox[{"hd", "[", 
                  RowBox[{"[", "ii", "]"}], "]"}]}], ",", 
                RowBox[{"{", 
                 RowBox[{"ii", ",", "1", ",", "nD"}], "}"}]}], "]"}], "-", 
              RowBox[{
               RowBox[{"PD", "[", 
                RowBox[{"[", "k", "]"}], "]"}], "*", 
               RowBox[{"hd", "[", 
                RowBox[{"[", "k", "]"}], "]"}]}], "+", 
              RowBox[{"Sum", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"PB", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "*", 
                 RowBox[{"hb", "[", 
                  RowBox[{"[", "i", "]"}], "]"}]}], ",", 
                RowBox[{"{", 
                 RowBox[{"i", ",", "1", ",", "nB"}], "}"}]}], "]"}]}], ")"}], 
            "/", "g"}]}], ")"}]}]}]}], "\[IndentingNewLine]", ")"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", 
     "**", "**", "**", "**"}], "******)"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"BGD", " ", "SINR", " ", "function"}], ",", " ", 
     RowBox[{"calculate", " ", 
      RowBox[{"b_k", "'"}], "s", " ", "SINR", " ", "given", " ", "k", " ", 
      "and", " ", "vector", " ", "PB"}], ",", " ", "PD"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SINRB", "[", 
      RowBox[{
      "p_", ",", "k_", ",", "PB_", ",", "PD_", ",", "hb_", ",", "hd_", ",", 
       "nB_", ",", "nD_"}], "]"}], ":=", 
     RowBox[{"(", "\[IndentingNewLine]", 
      RowBox[{"sbk", "=", 
       RowBox[{"p", "*", 
        RowBox[{
         RowBox[{"hb", "[", 
          RowBox[{"[", "k", "]"}], "]"}], "/", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"sigma", "^", "2"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Sum", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"PD", "[", 
                  RowBox[{"[", "ii", "]"}], "]"}], "*", 
                 RowBox[{"hd", "[", 
                  RowBox[{"[", "ii", "]"}], "]"}]}], ",", 
                RowBox[{"{", 
                 RowBox[{"ii", ",", "1", ",", "nD"}], "}"}]}], "]"}], "-", 
              RowBox[{
               RowBox[{"PB", "[", 
                RowBox[{"[", "k", "]"}], "]"}], "*", 
               RowBox[{"hb", "[", 
                RowBox[{"[", "k", "]"}], "]"}]}], "+", 
              RowBox[{"Sum", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"PB", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "*", 
                 RowBox[{"hb", "[", 
                  RowBox[{"[", "i", "]"}], "]"}]}], ",", 
                RowBox[{"{", 
                 RowBox[{"i", ",", "1", ",", "nB"}], "}"}]}], "]"}]}], ")"}], 
            "/", "g"}]}], ")"}]}]}]}], "\[IndentingNewLine]", ")"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**", "**", "**"}], "*****)"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"weight", " ", "factor", " ", "for", " ", "regret"}], ",", " ", 
     "BGD"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"wB", "[", 
      RowBox[{
      "pB_", ",", "k_", ",", "eta_", ",", "lambdaB_", ",", "lambdaD_", ",", 
       "wf_", ",", "nB_", ",", "nD_"}], "]"}], ":=", 
     RowBox[{"wf", "*", 
      RowBox[{"(", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"lambdaB", "[", 
             RowBox[{"[", "k", "]"}], "]"}], "/", 
            RowBox[{"(", "Rs", ")"}]}], "*", 
           RowBox[{"(", 
            RowBox[{"nB", "+", "nD"}], ")"}]}], ")"}], "^", "2"}], "*", 
        RowBox[{"pmax", "/", "eta"}]}], "\[IndentingNewLine]", ")"}]}]}], 
    ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**", "**", "**"}], "*****)"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"weight", " ", "factor", " ", "for", " ", "regret"}], ",", " ", 
     "DGD"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"wD", "[", 
      RowBox[{
      "pD_", ",", "k_", ",", "eta_", ",", "lambdaB_", ",", "lambdaD_", ",", 
       "wf_", ",", "nB_", ",", "nD_"}], "]"}], ":=", 
     RowBox[{"wf", "*", 
      RowBox[{"(", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"lambdaD", "[", 
             RowBox[{"[", "k", "]"}], "]"}], "/", 
            RowBox[{"(", "Rs", ")"}]}], "*", 
           RowBox[{"(", 
            RowBox[{"nB", "+", "nD"}], ")"}]}], ")"}], "^", "2"}], "*", 
        RowBox[{"pmax", "/", "eta"}]}], "\[IndentingNewLine]", ")"}]}]}], 
    ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**"}], 
    "*****)"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"**", "**", "**", "**", "**", "  ", "Utility"}], " ", "Function",
      " ", 
     RowBox[{"DGD", "**", "**"}], "*", 
     RowBox[{"**", "**", "**", "**", "**"}]}], "*****)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**", "**", "**", "**", "**", "**", "**"}], 
    "*****)"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"power", " ", "efficiency", " ", "function"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"feD", "[", 
      RowBox[{"p_", ",", "k_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"E", "^", 
         RowBox[{"(", 
          RowBox[{"-", 
           RowBox[{"SINRD", "[", 
            RowBox[{
            "p", ",", "k", ",", "pB", ",", "pD", ",", "hb", ",", "hd", ",", 
             "nB", ",", "nD"}], "]"}]}], ")"}]}]}], ")"}], "^", "m"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"regret", " ", "function"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"frD", "[", 
      RowBox[{"p_", ",", "k_"}], "]"}], ":=", 
     RowBox[{"E", "^", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "p"}], "/", 
        RowBox[{"wD", "[", 
         RowBox[{
         "pD", ",", "k", ",", "eta", ",", "lambdaB", ",", "lambdaD", ",", 
          "wf", ",", "nB", ",", "nD"}], "]"}]}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**", "**", "**"}], "*****)"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Total", " ", "efficiency", " ", "function", " ", "BGD"}], "*)"}],
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"fD", "[", 
      RowBox[{"p_", ",", "k_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"feD", "[", 
       RowBox[{"p", ",", "k"}], "]"}], "-", 
      RowBox[{"frD", "[", 
       RowBox[{"p", ",", "k"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Utility", " ", "function"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"uD", "[", 
      RowBox[{"p_", ",", "k_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"fD", "[", 
       RowBox[{"p", ",", "k"}], "]"}], "/", "p"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**", "**", "**", "**", "**", "**", "**"}], 
    "*****)"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"**", "**", "**", "**", " ", "Function"}], " ", "of", " ", 
     "best", " ", "response", " ", 
     RowBox[{"BGD", "**", "**"}], "*", "**"}], "******)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**", "**", "**", "**", "**", "**", "**"}], 
    "*****)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ReD", "[", 
      RowBox[{"p_", ",", "k_"}], "]"}], ":=", 
     RowBox[{"(", "\[IndentingNewLine]", 
      RowBox[{"p", "/.", " ", 
       RowBox[{"FindRoot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"p", "*", 
           RowBox[{"D", "[", 
            RowBox[{
             RowBox[{"fD", "[", 
              RowBox[{"p", ",", "k"}], "]"}], ",", "p"}], "]"}]}], "\[Equal]", 
          RowBox[{"fD", "[", 
           RowBox[{"p", ",", "k"}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"p", ",", "0.5"}], "}"}]}], "]"}]}], "\[IndentingNewLine]", 
      ")"}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**"}], 
    "*****)"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"**", "**", "**", "**", "**", "  ", "Utility"}], " ", "Function",
      " ", 
     RowBox[{"BGD", "**", "**", "**", "**", "**", "**", "**"}]}], "*****)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**", "**", "**", "**", "**", "**", "**"}], 
    "*****)"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"power", " ", "efficiency", " ", "function"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"feB", "[", 
      RowBox[{"p_", ",", "k_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"E", "^", 
         RowBox[{"(", 
          RowBox[{"-", 
           RowBox[{"SINRB", "[", 
            RowBox[{
            "p", ",", "k", ",", "pB", ",", "pD", ",", "hb", ",", "hd", ",", 
             "nB", ",", "nD"}], "]"}]}], ")"}]}]}], ")"}], "^", "m"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"regret", " ", "function"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"frB", "[", 
      RowBox[{"p_", ",", "k_"}], "]"}], ":=", 
     RowBox[{"E", "^", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "p"}], "/", 
        RowBox[{"wB", "[", 
         RowBox[{
         "pB", ",", "k", ",", "eta", ",", "lambdaB", ",", "lambdaD", ",", 
          "wf", ",", "nB", ",", "nD"}], "]"}]}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**", "**", "**"}], "*****)"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Total", " ", "efficiency", " ", "function", " ", "BGD"}], "*)"}],
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"fB", "[", 
      RowBox[{"p_", ",", "k_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"feB", "[", 
       RowBox[{"p", ",", "k"}], "]"}], "-", 
      RowBox[{"frB", "[", 
       RowBox[{"p", ",", "k"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Utility", " ", "function"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"uB", "[", 
      RowBox[{"p_", ",", "k_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"fB", "[", 
       RowBox[{"p", ",", "k"}], "]"}], "/", "p"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**", "**", "**", "**", "**", "**", "**"}], 
    "*****)"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"**", "**", "**", "**", " ", "Function"}], " ", "of", " ", 
     "best", " ", 
     RowBox[{"response", " ", "**", "**", "**", "**", "**"}]}], "******)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "**", "**", "**", "**", "**", "**", "**", "**", "**", " ", "BGDs", " ", "**",
      "**", "**", "**", "**", "**", "**", "**", "**", "**", "**"}], 
    "*****)"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**", "**", "**", "**", "**", "**", "**"}], 
    "*****)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ReB", "[", 
      RowBox[{"p_", ",", "k_"}], "]"}], ":=", 
     RowBox[{"(", "\[IndentingNewLine]", 
      RowBox[{"p", "/.", " ", 
       RowBox[{"FindRoot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"p", "*", 
           RowBox[{"D", "[", 
            RowBox[{
             RowBox[{"fB", "[", 
              RowBox[{"p", ",", "k"}], "]"}], ",", "p"}], "]"}]}], "\[Equal]", 
          RowBox[{"fB", "[", 
           RowBox[{"p", ",", "k"}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"p", ",", "0.5"}], "}"}]}], "]"}]}], "\[IndentingNewLine]", 
      ")"}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**", "**", "**", "**", "**"}], "******)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"**", "**", "**", "**", "**", "**", " ", "Evolutionary"}], " ", 
     "Search", " ", 
     RowBox[{"DGD", "**", "**"}], "*", "**"}], "*****)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"fEvoD", "[", 
      RowBox[{"nB_", ",", "nD_"}], "]"}], ":=", 
     RowBox[{"(", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Clear", "[", "tempP", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"tempP", "=", 
        RowBox[{"Array", "[", 
         RowBox[{"0", ",", "nD"}], "]"}]}], ";", 
       RowBox[{"(*", 
        RowBox[{"Last", " ", "used", " ", "power", " ", "vector"}], "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"Clear", "[", "pDreT", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"pDreT", "=", 
        RowBox[{"Array", "[", 
         RowBox[{"0", ",", "nD"}], "]"}]}], ";", 
       RowBox[{"(*", 
        RowBox[{"Calculated", " ", "best", " ", "response"}], "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"Clear", "[", "pDre", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"pDre", "=", 
        RowBox[{"Array", "[", 
         RowBox[{"0", ",", "nD"}], "]"}]}], ";", 
       RowBox[{"(*", 
        RowBox[{"Better", " ", "solution"}], "*)"}], "\[IndentingNewLine]", 
       RowBox[{"epsilon", "=", "0"}], ";", 
       RowBox[{"(*", 
        RowBox[{
        "Difference", " ", "between", " ", "calculation", " ", "and", " ", 
         "input"}], "*)"}], "\[IndentingNewLine]", 
       RowBox[{"tempep", "=", "1000000"}], ";", 
       RowBox[{"(*", 
        RowBox[{"Last", " ", "difference"}], "*)"}], "\[IndentingNewLine]", 
       RowBox[{"epTh", "=", 
        RowBox[{"10", "^", 
         RowBox[{"(", 
          RowBox[{"-", "15"}], ")"}]}]}], ";", 
       RowBox[{"(*", 
        RowBox[{"difference", " ", "threshold"}], "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"Itr", "=", "30"}], ";", "\[IndentingNewLine]", 
       RowBox[{"RandomS", "=", "10"}], ";", "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"iEvo", "=", "1"}], ",", 
         RowBox[{"iEvo", "<", 
          RowBox[{"RandomS", "+", "1"}]}], ",", 
         RowBox[{"iEvo", "++"}], ",", 
         RowBox[{"(*", 
          RowBox[{"Random", " ", "Start"}], "*)"}], "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"For", "[", 
           RowBox[{
            RowBox[{"nk", "=", "1"}], ",", 
            RowBox[{"nk", "<", 
             RowBox[{"nD", "+", "1"}]}], ",", 
            RowBox[{"nk", "++"}], ",", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{"pD", "[", 
               RowBox[{"[", "nk", "]"}], "]"}], "=", 
              RowBox[{"pmax", "*", 
               RowBox[{
                RowBox[{"RandomReal", "[", "]"}], "/", "4"}]}]}], ";"}]}], 
           "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
          "\[IndentingNewLine]", 
          RowBox[{"(*", 
           RowBox[{"Search", " ", "Itr", " ", "times"}], "*)"}], 
          "\[IndentingNewLine]", 
          RowBox[{"For", "[", 
           RowBox[{
            RowBox[{"jEvo", "=", "1"}], ",", 
            RowBox[{"jEvo", "<", 
             RowBox[{"Itr", "+", "1"}]}], ",", 
            RowBox[{"jEvo", "++"}], ",", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"tempP", "=", "pD"}], ";", "\[IndentingNewLine]", 
             "\[IndentingNewLine]", 
             RowBox[{"(*", 
              RowBox[{"Calculate", " ", "best", " ", "response"}], "*)"}], 
             "\[IndentingNewLine]", 
             RowBox[{"Clear", "[", "p", "]"}], ";", "\[IndentingNewLine]", 
             RowBox[{"For", "[", 
              RowBox[{
               RowBox[{"nk", "=", "1"}], ",", 
               RowBox[{"nk", "<", 
                RowBox[{"nD", "+", "1"}]}], ",", 
               RowBox[{"nk", "++"}], ",", "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{
                 RowBox[{"pDreT", "[", 
                  RowBox[{"[", "nk", "]"}], "]"}], "=", 
                 RowBox[{"ReD", "[", 
                  RowBox[{"p", ",", "nk"}], "]"}]}], ";"}]}], 
              "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
             RowBox[{"(*", 
              RowBox[{"Calculate", " ", "difference"}], "*)"}], 
             "\[IndentingNewLine]", 
             RowBox[{"Clear", "[", "nk", "]"}], ";", "\[IndentingNewLine]", 
             RowBox[{"epsilon", "=", 
              RowBox[{"Sum", "[", 
               RowBox[{
                RowBox[{"N", "[", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"tempP", "[", 
                    RowBox[{"[", "nk", "]"}], "]"}], "-", 
                    RowBox[{"pDreT", "[", 
                    RowBox[{"[", "nk", "]"}], "]"}]}], ")"}], "^", "2"}], 
                 "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{"nk", ",", "1", ",", "nD"}], "}"}]}], "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"(*", 
              RowBox[{"Update", " ", "better", " ", "solution"}], "*)"}], 
             "\[IndentingNewLine]", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"epsilon", "<", "tempep"}], ",", "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"tempep", "=", "epsilon"}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{"pDre", "=", "pDreT"}], ";"}]}], 
              "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
             RowBox[{"(*", 
              RowBox[{
              "Break", " ", "if", " ", "difference", " ", "is", " ", 
               "smaller", " ", "than", " ", "threshold"}], "*)"}], 
             "\[IndentingNewLine]", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"epsilon", "<", "epTh"}], ",", "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"pDre", "=", "pDreT"}], ";", "\[IndentingNewLine]", 
                RowBox[{"pD", "=", "pDreT"}], ";", 
                RowBox[{"(*", 
                 RowBox[{"update", " ", "power", " ", "vector"}], "*)"}], 
                "\[IndentingNewLine]", 
                RowBox[{"(*", "\[IndentingNewLine]", 
                 RowBox[{"(*", 
                  RowBox[{"Print", " ", "solution"}], "*)"}], 
                 "\[IndentingNewLine]", 
                 RowBox[{
                  RowBox[{"For", "[", 
                   RowBox[{
                    RowBox[{"nk", "=", "1"}], ",", 
                    RowBox[{"nk", "<", 
                    RowBox[{"nD", "+", "1"}]}], ",", 
                    RowBox[{"nk", "++"}], ",", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"Print", "[", 
                    RowBox[{
                    "\"\<P\>\"", ",", "nk", ",", "\"\< is: \>\"", ",", " ", 
                    RowBox[{"pDre", "[", 
                    RowBox[{"[", "nk", "]"}], "]"}]}], "]"}], ";"}]}], 
                   "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
                  RowBox[{"Print", "[", "tempep", "]"}], ";"}], 
                 "\[IndentingNewLine]", "*)"}], "\[IndentingNewLine]", 
                RowBox[{"Break", "[", "]"}], ";"}]}], "\[IndentingNewLine]", 
              "]"}], ";", "\[IndentingNewLine]", 
             RowBox[{"(*", 
              RowBox[{
              "Update", " ", "new", " ", "input", " ", "for", " ", "next", 
               " ", "iteration"}], "*)"}], "\[IndentingNewLine]", 
             RowBox[{"pD", "=", "pDreT"}], ";"}]}], "\[IndentingNewLine]", 
           "]"}], ";", "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"epsilon", "<", "epTh"}], ",", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"Break", "[", "]"}], ";"}]}], "\[IndentingNewLine]", 
           "]"}], ";"}]}], "\[IndentingNewLine]", "]"}], ";"}], 
      "\[IndentingNewLine]", 
      RowBox[{"(*", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Print", "[", 
         RowBox[{"\"\<pB: \>\"", ",", " ", "pB"}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"Print", "[", 
         RowBox[{"\"\<pD: \>\"", ",", "pD"}], "]"}], ";"}], 
       "\[IndentingNewLine]", "*)"}], "\[IndentingNewLine]", ")"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**"}], "*****)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**", "**", "**", "**", "**"}], "******)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"**", "**", "**", "**", "**", "**", " ", "Evolutionary"}], " ", 
     "Search", " ", 
     RowBox[{"BGDs", "**", "**", "**", "**", "**"}]}], "*****)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"fEvoB", "[", 
      RowBox[{"nB_", ",", "nD_"}], "]"}], ":=", 
     RowBox[{"(", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Clear", "[", "tempP", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"tempP", "=", 
        RowBox[{"Array", "[", 
         RowBox[{"0", ",", "nB"}], "]"}]}], ";", 
       RowBox[{"(*", 
        RowBox[{"Last", " ", "used", " ", "power", " ", "vector"}], "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"Clear", "[", "pBreT", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"pBreT", "=", 
        RowBox[{"Array", "[", 
         RowBox[{"0", ",", "nB"}], "]"}]}], ";", 
       RowBox[{"(*", 
        RowBox[{"Calculated", " ", "best", " ", "response"}], "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"Clear", "[", "pBre", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"pBre", "=", 
        RowBox[{"Array", "[", 
         RowBox[{"0", ",", "nB"}], "]"}]}], ";", 
       RowBox[{"(*", 
        RowBox[{"Better", " ", "solution"}], "*)"}], "\[IndentingNewLine]", 
       RowBox[{"epsilon", "=", "0"}], ";", 
       RowBox[{"(*", 
        RowBox[{
        "Difference", " ", "between", " ", "calculation", " ", "and", " ", 
         "input"}], "*)"}], "\[IndentingNewLine]", 
       RowBox[{"tempep", "=", "1000000"}], ";", 
       RowBox[{"(*", 
        RowBox[{"Last", " ", "difference"}], "*)"}], "\[IndentingNewLine]", 
       RowBox[{"epTh", "=", 
        RowBox[{"10", "^", 
         RowBox[{"(", 
          RowBox[{"-", "10"}], ")"}]}]}], ";", 
       RowBox[{"(*", 
        RowBox[{"difference", " ", "threshold"}], "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"Itr", "=", "30"}], ";", "\[IndentingNewLine]", 
       RowBox[{"RandomS", "=", "10"}], ";", "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"iEvo", "=", "1"}], ",", 
         RowBox[{"iEvo", "<", 
          RowBox[{"RandomS", "+", "1"}]}], ",", 
         RowBox[{"iEvo", "++"}], ",", 
         RowBox[{"(*", 
          RowBox[{"Random", " ", "Start"}], "*)"}], "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"For", "[", 
           RowBox[{
            RowBox[{"nk", "=", "1"}], ",", 
            RowBox[{"nk", "<", 
             RowBox[{"nB", "+", "1"}]}], ",", 
            RowBox[{"nk", "++"}], ",", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{"pB", "[", 
               RowBox[{"[", "nk", "]"}], "]"}], "=", 
              RowBox[{"pmax", "*", 
               RowBox[{
                RowBox[{"RandomReal", "[", "]"}], "/", "4"}]}]}], ";"}]}], 
           "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
          "\[IndentingNewLine]", 
          RowBox[{"(*", 
           RowBox[{"Search", " ", "Itr", " ", "times"}], "*)"}], 
          "\[IndentingNewLine]", 
          RowBox[{"For", "[", 
           RowBox[{
            RowBox[{"jEvo", "=", "1"}], ",", 
            RowBox[{"jEvo", "<", 
             RowBox[{"Itr", "+", "1"}]}], ",", 
            RowBox[{"jEvo", "++"}], ",", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"tempP", "=", "pB"}], ";", "\[IndentingNewLine]", 
             "\[IndentingNewLine]", 
             RowBox[{"(*", 
              RowBox[{"Calculate", " ", "best", " ", "response"}], "*)"}], 
             "\[IndentingNewLine]", 
             RowBox[{"Clear", "[", "p", "]"}], ";", "\[IndentingNewLine]", 
             RowBox[{"For", "[", 
              RowBox[{
               RowBox[{"nk", "=", "1"}], ",", 
               RowBox[{"nk", "<", 
                RowBox[{"nB", "+", "1"}]}], ",", 
               RowBox[{"nk", "++"}], ",", "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{
                 RowBox[{"pBreT", "[", 
                  RowBox[{"[", "nk", "]"}], "]"}], "=", 
                 RowBox[{"ReB", "[", 
                  RowBox[{"p", ",", "nk"}], "]"}]}], ";"}]}], 
              "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
             "\[IndentingNewLine]", 
             RowBox[{"(*", 
              RowBox[{"Calculate", " ", "difference"}], "*)"}], 
             "\[IndentingNewLine]", 
             RowBox[{"Clear", "[", "nk", "]"}], ";", "\[IndentingNewLine]", 
             RowBox[{"epsilon", "=", 
              RowBox[{"Sum", "[", 
               RowBox[{
                RowBox[{"N", "[", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"tempP", "[", 
                    RowBox[{"[", "nk", "]"}], "]"}], "-", 
                    RowBox[{"pBreT", "[", 
                    RowBox[{"[", "nk", "]"}], "]"}]}], ")"}], "^", "2"}], 
                 "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{"nk", ",", "1", ",", "nB"}], "}"}]}], "]"}]}], ";", 
             "\[IndentingNewLine]", "\[IndentingNewLine]", 
             RowBox[{"(*", 
              RowBox[{"Update", " ", "better", " ", "solution"}], "*)"}], 
             "\[IndentingNewLine]", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"epsilon", "<", "tempep"}], ",", "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"tempep", "=", "epsilon"}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{"pBre", "=", "pBreT"}], ";"}]}], 
              "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
             RowBox[{"(*", 
              RowBox[{
              "Break", " ", "if", " ", "difference", " ", "is", " ", 
               "smaller", " ", "than", " ", "threshold"}], "*)"}], 
             "\[IndentingNewLine]", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"epsilon", "<", "epTh"}], ",", "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"pBre", "=", "pBreT"}], ";", "\[IndentingNewLine]", 
                RowBox[{"pB", "=", "pBreT"}], ";", "\[IndentingNewLine]", 
                RowBox[{"(*", "\[IndentingNewLine]", 
                 RowBox[{"(*", 
                  RowBox[{"Print", " ", "solution"}], "*)"}], 
                 "\[IndentingNewLine]", 
                 RowBox[{
                  RowBox[{"For", "[", 
                   RowBox[{
                    RowBox[{"nk", "=", "1"}], ",", 
                    RowBox[{"nk", "<", 
                    RowBox[{"nB", "+", "1"}]}], ",", 
                    RowBox[{"nk", "++"}], ",", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"Print", "[", 
                    RowBox[{
                    "\"\<P\>\"", ",", "nk", ",", "\"\< is: \>\"", ",", " ", 
                    RowBox[{"pBre", "[", 
                    RowBox[{"[", "nk", "]"}], "]"}]}], "]"}], ";"}]}], 
                   "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
                  RowBox[{"Print", "[", "tempep", "]"}], ";"}], 
                 "\[IndentingNewLine]", "*)"}], "\[IndentingNewLine]", 
                RowBox[{"Break", "[", "]"}], ";"}]}], "\[IndentingNewLine]", 
              "]"}], ";", "\[IndentingNewLine]", 
             RowBox[{"(*", 
              RowBox[{
              "Update", " ", "new", " ", "input", " ", "for", " ", "next", 
               " ", "iteration"}], "*)"}], "\[IndentingNewLine]", 
             RowBox[{"pB", "=", "pBreT"}], ";"}]}], "\[IndentingNewLine]", 
           "]"}], ";", "\[IndentingNewLine]", 
          RowBox[{"(*", 
           RowBox[{"Break", " ", "if", " ", "NE", " ", "is", " ", "found"}], 
           "*)"}], "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"epsilon", "<", "epTh"}], ",", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"Break", "[", "]"}], ";"}]}], "\[IndentingNewLine]", 
           "]"}], ";"}]}], "\[IndentingNewLine]", "]"}], ";"}], 
      "\[IndentingNewLine]", 
      RowBox[{"(*", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{"Print", " ", "solution"}], "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"For", "[", 
         RowBox[{
          RowBox[{"nk", "=", "1"}], ",", 
          RowBox[{"nk", "<", 
           RowBox[{"nB", "+", "1"}]}], ",", 
          RowBox[{"nk", "++"}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Print", "[", 
            RowBox[{"\"\<P\>\"", ",", "nk", ",", "\"\< is: \>\"", ",", " ", 
             RowBox[{"pBre", "[", 
              RowBox[{"[", "nk", "]"}], "]"}]}], "]"}], ";"}]}], 
         "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"Print", "[", "tempep", "]"}], ";"}], "\[IndentingNewLine]", 
       "*)"}], "\[IndentingNewLine]", 
      RowBox[{"(*", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Print", "[", 
         RowBox[{"\"\<pB: \>\"", ",", " ", "pB"}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"Print", "[", 
         RowBox[{"\"\<pD: \>\"", ",", "pD"}], "]"}], ";"}], 
       "\[IndentingNewLine]", "*)"}], "\[IndentingNewLine]", ")"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**", "**", "**"}], "*****)"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"**", "**", "**", " ", "Main"}], " ", "function", " ", "to", " ",
      "find", " ", "SE"}], " ", "***********)"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**", "**", "**"}], "*****)"}], "\[IndentingNewLine]",
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"fSE", "[", 
      RowBox[{"nB_", ",", "nD_"}], "]"}], ":=", 
     RowBox[{"(", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"ItrSE", "=", "30"}], ";", "\[IndentingNewLine]", 
       RowBox[{"Clear", "[", "pDtemp", "]"}], ";", 
       RowBox[{"(*", 
        RowBox[{"Record", " ", "current", " ", "pD", " ", "vector"}], "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"pDtemp", "=", 
        RowBox[{"Array", "[", 
         RowBox[{"0", ",", "nD"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Clear", "[", "pBtemp", "]"}], ";", 
       RowBox[{"(*", 
        RowBox[{"Record", " ", "current", " ", "pB", " ", "vector"}], "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"pBtemp", "=", 
        RowBox[{"Array", "[", 
         RowBox[{"0", ",", "nB"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Clear", "[", "pBsol", "]"}], ";", 
       RowBox[{"(*", 
        RowBox[{"pB", " ", "solution"}], "*)"}], "\[IndentingNewLine]", 
       RowBox[{"pBsol", "=", 
        RowBox[{"Array", "[", 
         RowBox[{"0", ",", "nB"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Clear", "[", "pDsol", "]"}], ";", 
       RowBox[{"(*", 
        RowBox[{"pD", " ", "solution"}], "*)"}], "\[IndentingNewLine]", 
       RowBox[{"pDsol", "=", 
        RowBox[{"Array", "[", 
         RowBox[{"0", ",", "nD"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"eptp", "=", "10000"}], ";", "\[IndentingNewLine]", 
       RowBox[{"epSE", "=", "0"}], ";", "\[IndentingNewLine]", 
       RowBox[{"epSEth", "=", 
        RowBox[{"10", "^", 
         RowBox[{"(", 
          RowBox[{"-", "10"}], ")"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"iSE", "=", "1"}], ",", 
         RowBox[{"iSE", "<", 
          RowBox[{"ItrSE", "+", "1"}]}], ",", 
         RowBox[{"iSE", "++"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"pDtemp", "=", "pD"}], ";", 
          RowBox[{"(*", 
           RowBox[{"Record", " ", "current", " ", "pD", " ", "vector"}], 
           "*)"}], "\[IndentingNewLine]", 
          RowBox[{"fEvoB", "[", 
           RowBox[{"nB", ",", "nD"}], "]"}], ";", 
          RowBox[{"(*", 
           RowBox[{"Find", " ", "BGD", " ", "NE"}], "*)"}], 
          "\[IndentingNewLine]", 
          RowBox[{"pBtemp", "=", "pB"}], ";", 
          RowBox[{"(*", 
           RowBox[{"Record", " ", "current", " ", "pB", " ", "vector"}], 
           "*)"}], "\[IndentingNewLine]", 
          RowBox[{"fEvoD", "[", 
           RowBox[{"nB", ",", "nD"}], "]"}], ";", " ", 
          RowBox[{"(*", 
           RowBox[{"Find", " ", "DGD", " ", "NE"}], "*)"}], 
          "\[IndentingNewLine]", 
          RowBox[{"epSE", "=", 
           RowBox[{"Sum", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"pDtemp", "[", 
                 RowBox[{"[", "nk", "]"}], "]"}], "-", 
                RowBox[{"pD", "[", 
                 RowBox[{"[", "nk", "]"}], "]"}]}], ")"}], "^", "2"}], ",", 
             RowBox[{"{", 
              RowBox[{"nk", ",", "1", ",", "nD"}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"epSE", "<", "eptp"}], ",", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"eptp", "=", "epSE"}], ";", "\[IndentingNewLine]", 
             RowBox[{"pBsol", "=", "pB"}], ";", 
             RowBox[{"(*", 
              RowBox[{"pB", " ", "solution"}], "*)"}], "\[IndentingNewLine]", 
             RowBox[{"pDsol", "=", "pD"}], ";"}]}], 
           RowBox[{"(*", 
            RowBox[{"pD", " ", "solution"}], "*)"}], "\[IndentingNewLine]", 
           "]"}], ";", "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"epSE", "<", "epSEth"}], ",", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"Break", "[", "]"}], ";"}]}], 
           RowBox[{"(*", 
            RowBox[{"Break", " ", "if", " ", "below", " ", "threshold"}], 
            "*)"}], "\[IndentingNewLine]", "]"}], ";"}]}], 
        "\[IndentingNewLine]", "]"}], ";"}], "\[IndentingNewLine]", 
      RowBox[{"(*", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Print", "[", 
         RowBox[{"\"\<pB is \>\"", ",", "pBsol"}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"Print", "[", 
         RowBox[{"\"\<pD is \>\"", ",", " ", "pDsol"}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"Print", "[", 
         RowBox[{"\"\<Distance to real SE \>\"", ",", "eptp"}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"Print", "[", 
         RowBox[{"\"\<Iterations to convergence: \>\"", ",", "iSE"}], "]"}]}],
        "\[IndentingNewLine]", "*)"}], "\[IndentingNewLine]", ")"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**"}], "*****)"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"**", "**", "**", "**"}], "*", "  ", 
     RowBox[{"Simulation", " ", "**", "**", "**", "**", "**"}]}], "*****)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"**", "**", "**", "Total"}], " ", "power", " ", "usage"}], 
    "****)"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Initial", " ", "pB", " ", "and", " ", "PD"}], " ", "***)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pD", "=", 
     RowBox[{"{", 
      RowBox[{
      ".6535548112405387`", ",", ".542633033382646`", ",", 
       ".557613884118325`", ",", ".5185569731810117`", ",", 
       ".5610489357825246`"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pB", "=", 
     RowBox[{"{", 
      RowBox[{
      ".5396399729340547`", ",", ".3662039814911275`", ",", 
       ".402259711410245`", ",", ".4457510928592003`", ",", 
       ".495060731610103`", ",", ".5385387302101354`", ",", 
       ".7505445029925895`"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"simItr", "=", "20"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"sMTotal", "=", "0"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", "ptotal", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", "intotal", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", "outtotal", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", "retotal", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pbTotal", "=", 
     RowBox[{"Array", "[", 
      RowBox[{"0", ",", "simItr"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pdTotal", "=", 
     RowBox[{"Array", "[", 
      RowBox[{"0", ",", "simItr"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ptotal", "=", 
     RowBox[{"Array", "[", 
      RowBox[{"0", ",", "simItr"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"intotal", "=", 
     RowBox[{"Array", "[", 
      RowBox[{"0", ",", "simItr"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"outtotal", "=", 
     RowBox[{"Array", "[", 
      RowBox[{"0", ",", "simItr"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"retotal", "=", 
     RowBox[{"Array", "[", 
      RowBox[{"0", ",", "simItr"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Initial", " ", "2000", " ", "smart", " ", "meters"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", "sM", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"sM", "=", 
     RowBox[{"Array", "[", 
      RowBox[{"0", ",", "2000"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**", "**"}], "******)"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Different", " ", 
     RowBox[{
     "wf", " ", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", 
      "**"}]}], "*****)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"cccc", "=", 
     RowBox[{"{", 
      RowBox[{"0.1", ",", "0.15", ",", "0.2", ",", "0.25", ",", "0.3"}], 
      "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"jjj", "=", "1"}], ",", 
      RowBox[{"jjj", "<", "6"}], ",", 
      RowBox[{"jjj", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"wf", "=", 
        RowBox[{"cccc", "[", 
         RowBox[{"[", "jjj", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"isim", "=", "1"}], ",", 
         RowBox[{"isim", "<", 
          RowBox[{"simItr", "+", "1"}]}], ",", 
         RowBox[{"isim", "++"}], ",", "\[IndentingNewLine]", 
         "\[IndentingNewLine]", 
         RowBox[{"(*", 
          RowBox[{"(*", 
           RowBox[{"Smart", " ", "meter", " ", "data"}], "*)"}], 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"For", "[", 
            RowBox[{
             RowBox[{"isM", "=", "1"}], ",", 
             RowBox[{"isM", "<", "661"}], ",", 
             RowBox[{"isM", "++"}], ",", 
             RowBox[{"(*", 
              RowBox[{"Randomly", " ", "generated", " ", "data"}], "*)"}], 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{
               RowBox[{"sM", "[", 
                RowBox[{"[", "isM", "]"}], "]"}], "=", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"36", "+", 
                  RowBox[{
                   RowBox[{"64", "/", "simItr"}], "*", "isim"}]}], ")"}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"62", "-", 
                   RowBox[{
                    RowBox[{"64", "/", "simItr"}], "*", "isim"}]}], ")"}], 
                 "*", 
                 RowBox[{"RandomReal", "[", "]"}]}]}]}], ";"}]}], 
            "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
           RowBox[{"For", "[", 
            RowBox[{
             RowBox[{"isM", "=", "661"}], ",", 
             RowBox[{"isM", "<", "1251"}], ",", 
             RowBox[{"isM", "++"}], ",", 
             RowBox[{"(*", 
              RowBox[{"Randomly", " ", "generated", " ", "data"}], "*)"}], 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{
               RowBox[{"sM", "[", 
                RowBox[{"[", "isM", "]"}], "]"}], "=", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"32", "+", 
                  RowBox[{
                   RowBox[{"64", "/", "simItr"}], "*", "isim"}]}], ")"}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"64", "-", 
                   RowBox[{
                    RowBox[{"64", "/", "simItr"}], "*", "isim"}]}], ")"}], 
                 "*", 
                 RowBox[{"RandomReal", "[", "]"}]}]}]}], ";"}]}], 
            "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
           RowBox[{"For", "[", 
            RowBox[{
             RowBox[{"isM", "=", "1251"}], ",", 
             RowBox[{"isM", "<", "2001"}], ",", 
             RowBox[{"isM", "++"}], ",", 
             RowBox[{"(*", 
              RowBox[{"Randomly", " ", "generated", " ", "data"}], "*)"}], 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{
               RowBox[{"sM", "[", 
                RowBox[{"[", "isM", "]"}], "]"}], "=", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"24", "+", 
                  RowBox[{
                   RowBox[{"72", "/", "simItr"}], "*", "isim"}]}], ")"}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"72", "-", 
                   RowBox[{
                    RowBox[{"72", "/", "simItr"}], "*", "isim"}]}], ")"}], 
                 "*", 
                 RowBox[{"RandomReal", "[", "]"}]}]}]}], ";"}]}], 
            "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
           RowBox[{"sMTotal", "=", 
            RowBox[{"Sum", "[", 
             RowBox[{
              RowBox[{"sM", "[", 
               RowBox[{"[", "isM", "]"}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"isM", ",", "1", ",", "2000"}], "}"}]}], "]"}]}], 
           ";"}], "\[IndentingNewLine]", "*)"}], "\[IndentingNewLine]", 
         RowBox[{"(*", 
          RowBox[{"Assign", " ", "lambda"}], "*)"}], "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"For", "[", 
           RowBox[{
            RowBox[{"i", "=", "1"}], ",", 
            RowBox[{"i", "<", 
             RowBox[{"nB", "+", "1"}]}], ",", 
            RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{"lambdaB", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "=", 
              RowBox[{"12000", "+", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", "isim", ")"}], "/", "simItr"}], "*", 
                "4000"}]}]}], ";"}]}], "\[IndentingNewLine]", "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"(*", 
           RowBox[{"Incoming", " ", "data", " ", "rate", " ", "DGD"}], "*)"}],
           "\[IndentingNewLine]", 
          RowBox[{"For", "[", 
           RowBox[{
            RowBox[{"i", "=", "1"}], ",", 
            RowBox[{"i", "<", 
             RowBox[{"nD", "+", "1"}]}], ",", 
            RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{"lambdaD", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "=", 
              RowBox[{"12000", "+", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", "isim", ")"}], "/", "simItr"}], "*", 
                "4000"}]}]}], ";"}]}], "\[IndentingNewLine]", "]"}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"intotal", "[", 
            RowBox[{"[", "isim", "]"}], "]"}], "=", 
           RowBox[{
            RowBox[{"Sum", "[", 
             RowBox[{
              RowBox[{"lambdaB", "[", 
               RowBox[{"[", "i", "]"}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", "1", ",", "nB"}], "}"}]}], "]"}], "+", 
            RowBox[{"Sum", "[", 
             RowBox[{
              RowBox[{"lambdaD", "[", 
               RowBox[{"[", "j", "]"}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"j", ",", "1", ",", "nD"}], "}"}]}], "]"}]}]}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]",
           "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"(*", 
           RowBox[{"Calculate", " ", "SE"}], "*)"}], "\[IndentingNewLine]", 
          RowBox[{"fSE", "[", 
           RowBox[{"nB", ",", "nD"}], "]"}], ";", "\[IndentingNewLine]", 
          RowBox[{"(*", 
           RowBox[{"Transmitting", " ", "data", " ", "rate"}], "*)"}], 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"outtotal", "[", 
            RowBox[{"[", "isim", "]"}], "]"}], "=", 
           RowBox[{
            RowBox[{"Sum", "[", 
             RowBox[{
              RowBox[{"Rb", "*", 
               RowBox[{"feB", "[", 
                RowBox[{
                 RowBox[{"pB", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], ",", "i"}], "]"}]}], ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", "1", ",", "nB"}], "}"}]}], "]"}], "+", 
            RowBox[{"Sum", "[", 
             RowBox[{
              RowBox[{"Rd", "*", 
               RowBox[{"feD", "[", 
                RowBox[{
                 RowBox[{"pD", "[", 
                  RowBox[{"[", "j", "]"}], "]"}], ",", "j"}], "]"}]}], ",", 
              RowBox[{"{", 
               RowBox[{"j", ",", "1", ",", "nD"}], "}"}]}], "]"}]}]}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"(*", "Reliability", "*)"}], "\[IndentingNewLine]", 
          RowBox[{"rel", "=", 
           RowBox[{"N", "[", 
            RowBox[{
             RowBox[{"outtotal", "[", 
              RowBox[{"[", "isim", "]"}], "]"}], "/", 
             RowBox[{"intotal", "[", 
              RowBox[{"[", "isim", "]"}], "]"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"rel", ">", "1"}], ",", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"retotal", "[", 
              RowBox[{"[", "isim", "]"}], "]"}], "=", "1"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"retotal", "[", 
              RowBox[{"[", "isim", "]"}], "]"}], "=", "rel"}]}], 
           "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"pbTotal", "[", 
            RowBox[{"[", "isim", "]"}], "]"}], "=", 
           RowBox[{"Sum", "[", 
            RowBox[{
             RowBox[{"pB", "[", 
              RowBox[{"[", "nk", "]"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"nk", ",", "1", ",", "nB"}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"pdTotal", "[", 
            RowBox[{"[", "isim", "]"}], "]"}], "=", 
           RowBox[{"Sum", "[", 
            RowBox[{
             RowBox[{"pD", "[", 
              RowBox[{"[", "nk", "]"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"nk", ",", "1", ",", "nD"}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"ptotal", "[", 
            RowBox[{"[", "isim", "]"}], "]"}], "=", 
           RowBox[{
            RowBox[{"pbTotal", "[", 
             RowBox[{"[", "isim", "]"}], "]"}], "+", 
            RowBox[{"pdTotal", "[", 
             RowBox[{"[", "isim", "]"}], "]"}]}]}], ";"}]}], 
        "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\<c=\>\"", ",", "wf"}], "]"}], ";", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\<Total power: \>\"", ",", "ptotal"}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\<Total incoming: \>\"", ",", "intotal"}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\<Total outgoing: \>\"", ",", "outtotal"}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\<Reliability: \>\"", ",", "retotal"}], "]"}], ";"}]}], 
     "\[IndentingNewLine]", "]"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.582390133315487*^9, 3.5823901597708817`*^9}, {
   3.5824587613329706`*^9, 3.5824587929542265`*^9}, {3.58246633538907*^9, 
   3.582466432619206*^9}, {3.582466548009368*^9, 3.5824667475196466`*^9}, {
   3.582466848014943*^9, 3.582466885995038*^9}, {3.5824669424926805`*^9, 
   3.5824669528502493`*^9}, {3.5824673824866505`*^9, 
   3.5824673914617147`*^9}, {3.582467513989582*^9, 3.5824676848977613`*^9}, {
   3.582467719334854*^9, 3.5824677786625395`*^9}, {3.5824678093501453`*^9, 
   3.582467818695165*^9}, {3.5824683672365932`*^9, 3.582468617254799*^9}, {
   3.5824686729400816`*^9, 3.5824689087232275`*^9}, {3.582468938985804*^9, 
   3.582469071213631*^9}, {3.5824691066287146`*^9, 3.5824691576638956`*^9}, {
   3.582469201139039*^9, 3.58246920133904*^9}, {3.5824692345716343`*^9, 
   3.582469360752029*^9}, {3.582472810222189*^9, 3.5824730432241983`*^9}, {
   3.582473113595922*^9, 3.5824732921694355`*^9}, {3.5824733374095154`*^9, 
   3.582473602625581*^9}, {3.5824739726426306`*^9, 3.58247402357672*^9}, {
   3.5824740684735994`*^9, 3.582474202009834*^9}, {3.582474277701167*^9, 
   3.5824744813595247`*^9}, {3.5824745889685135`*^9, 
   3.5824746397622023`*^9}, {3.582474714408334*^9, 3.582474714689134*^9}, {
   3.5825083324121323`*^9, 3.582508346454652*^9}, {3.582508410021744*^9, 
   3.5825086982036552`*^9}, {3.5825093146305413`*^9, 3.582509401284668*^9}, {
   3.5825094380867205`*^9, 3.582509442817727*^9}, {3.582509497604805*^9, 
   3.5825095095783224`*^9}, {3.582509562589897*^9, 3.582509706656602*^9}, {
   3.5825616159366665`*^9, 3.5825616338566923`*^9}, {3.582561672556746*^9, 
   3.5825619785271745`*^9}, {3.582562018927231*^9, 3.5825620734973073`*^9}, {
   3.582562264417575*^9, 3.582562293787616*^9}, {3.5825623362676754`*^9, 
   3.582562516217927*^9}, {3.5825625655379963`*^9, 3.5825626944581766`*^9}, {
   3.582562727978224*^9, 3.582562745028248*^9}, {3.5825627881683083`*^9, 
   3.582562881918439*^9}, {3.5825629249084997`*^9, 3.5825629441385264`*^9}, {
   3.582562984718583*^9, 3.582562985468584*^9}, {3.5825630750787096`*^9, 
   3.582563123078777*^9}, {3.582563166938838*^9, 3.582563167108838*^9}, {
   3.5825632151889057`*^9, 3.5825632539089603`*^9}, {3.582563288539008*^9, 
   3.582563295349018*^9}, {3.5825633272090626`*^9, 3.5825633292190657`*^9}, {
   3.5825636466095095`*^9, 3.582563752979659*^9}, {3.5825639155098863`*^9, 
   3.5825639157398863`*^9}, {3.5825639504699354`*^9, 3.582563951919937*^9}, {
   3.582563989229989*^9, 3.5825640786501145`*^9}, {3.5825641197501717`*^9, 
   3.58256424673035*^9}, {3.5825643916805525`*^9, 3.582564808171136*^9}, {
   3.5825648437611856`*^9, 3.582564973911368*^9}, {3.58263114553473*^9, 
   3.582631386913954*^9}, 3.5826326840661235`*^9, {3.58263272177139*^9, 
   3.5826327693514733`*^9}, {3.5826328890271077`*^9, 
   3.5826329285731773`*^9}, {3.582632962456436*^9, 3.5826329627060366`*^9}, {
   3.5826330020805063`*^9, 3.5826330331245604`*^9}, {3.5826331582527895`*^9, 
   3.5826331614039946`*^9}, {3.582633231363318*^9, 3.582633254578159*^9}, {
   3.5826333094122553`*^9, 3.58263331817947*^9}, {3.5826333666799555`*^9, 
   3.5826334996389894`*^9}, {3.582633548974276*^9, 3.5826335836603374`*^9}, {
   3.5826341230156846`*^9, 3.582634178426982*^9}, {3.5826342238734846`*^9, 
   3.5826346173521757`*^9}, {3.5826346816398883`*^9, 
   3.5826347273479686`*^9}, {3.582634788344076*^9, 3.582634788921277*^9}, {
   3.582634848180484*^9, 3.5826350361608133`*^9}, {3.58263506814087*^9, 
   3.582635092024512*^9}, {3.582638672768433*^9, 3.582638719006914*^9}, {
   3.5826388111911798`*^9, 3.582638845974241*^9}, {3.5826388772990956`*^9, 
   3.582638921275573*^9}, {3.582639031299471*^9, 3.582639031783072*^9}, {
   3.582639130016444*^9, 3.582639156286891*^9}, {3.582641052562153*^9, 
   3.582641070112177*^9}, {3.58264113614227*^9, 3.5826411498222885`*^9}, {
   3.5826412394924145`*^9, 3.582641346342564*^9}, {3.582641391252627*^9, 
   3.5826413916126275`*^9}, 3.5826414366126904`*^9, {3.5826414716627398`*^9, 
   3.5826414807727523`*^9}, {3.5826417707831583`*^9, 3.582641811883216*^9}, {
   3.5826418421532583`*^9, 3.5826418695632963`*^9}, {3.582641899933339*^9, 
   3.5826420353235283`*^9}, {3.582642065823571*^9, 3.5826422361838098`*^9}, {
   3.582642370143997*^9, 3.582642433524086*^9}, {3.582642472594141*^9, 
   3.582642526394216*^9}, {3.582642567114273*^9, 3.5826426030943236`*^9}, {
   3.5826426541343946`*^9, 3.5826426997044587`*^9}, {3.5826440252123327`*^9, 
   3.582644082052412*^9}, {3.582644158102519*^9, 3.5826442114125934`*^9}, {
   3.582644246192642*^9, 3.5826442644526677`*^9}, {3.582646906078367*^9, 
   3.582646923488392*^9}, {3.58265711328228*^9, 3.5826573684470444`*^9}, {
   3.582657420441936*^9, 3.5826575565365753`*^9}, {3.5826576103254695`*^9, 
   3.5826577012268295`*^9}, {3.582657763829739*^9, 3.5826578142646275`*^9}, {
   3.58265786086191*^9, 3.5826578644187155`*^9}, {3.5826579337296376`*^9, 
   3.5826579718561044`*^9}, {3.5826580499186416`*^9, 
   3.5826580544894495`*^9}, {3.5826581735488586`*^9, 3.5826581819416733`*^9}, 
   3.5826582885283237`*^9, {3.582658319126193*^9, 3.5826583413619385`*^9}, {
   3.582666618511545*^9, 3.582666634664877*^9}, {3.582666748760707*^9, 
   3.582666756449222*^9}, {3.5826669145260406`*^9, 3.5826669618942366`*^9}, {
   3.582667054312626*^9, 3.5826670739774666`*^9}, {3.582667114576949*^9, 
   3.5826671239653683`*^9}, 3.582670597699437*^9, {3.5826716866663847`*^9, 
   3.582671756030416*^9}, {3.58267195837597*^9, 3.582671997148264*^9}, {
   3.5826721700136046`*^9, 3.5826723649041276`*^9}, {3.582672397287851*^9, 
   3.582672404510397*^9}, {3.582672450059743*^9, 3.5826724754684973`*^9}, {
   3.5826725440910263`*^9, 3.582672612691058*^9}, {3.582672644885817*^9, 
   3.582672649948356*^9}, {3.5826726960582333`*^9, 3.5826727434006104`*^9}, {
   3.582672837510811*^9, 3.58267288386718*^9}, {3.582673317459586*^9, 
   3.5826733177816877`*^9}, {3.582673386002614*^9, 3.5826733943018284`*^9}, {
   3.582673430213092*^9, 3.58267344068071*^9}, {3.582673489212395*^9, 
   3.582673489383995*^9}, {3.5826788239895287`*^9, 3.5826788820570345`*^9}, {
   3.5826789388220415`*^9, 3.5826790018072557`*^9}, {3.5826790320858097`*^9, 
   3.582679055846053*^9}, 3.582679100165333*^9, {3.5826791366105003`*^9, 
   3.5826791657895527`*^9}, {3.5826792304190702`*^9, 3.582679246664999*^9}, {
   3.5826793024230003`*^9, 3.582679311600917*^9}, {3.582680038822505*^9, 
   3.5826800640160503`*^9}, {3.58268012469556*^9, 3.582680216879731*^9}, {
   3.5826802779049416`*^9, 3.5826802782974424`*^9}, {3.58268034851927*^9, 
   3.5826803967099576`*^9}, {3.5827264448278804`*^9, 
   3.5827264878023386`*^9}, {3.5827266214099803`*^9, 
   3.5827266442112846`*^9}, {3.582726679708315*^9, 3.5827267411378284`*^9}, {
   3.582726777127887*^9, 3.582726809139718*^9}, {3.582727090208794*^9, 
   3.5827271183764052`*^9}, {3.5827271559615545`*^9, 3.582727218769147*^9}, {
   3.5827272856629734`*^9, 3.582727285882986*^9}, {3.5827275767626233`*^9, 
   3.582727613572729*^9}, {3.582727644509498*^9, 3.582727646721625*^9}, {
   3.58272785522155*^9, 3.5827278617329226`*^9}, {3.582728063481462*^9, 
   3.582728071032894*^9}, 3.5827297977876587`*^9, {3.582730811059614*^9, 
   3.5827308282615986`*^9}, {3.582730928366324*^9, 3.582730966224489*^9}, {
   3.582730998021308*^9, 3.582730998622342*^9}, {3.5827320409259586`*^9, 
   3.5827320971801767`*^9}, {3.582732137875504*^9, 3.5827322572763333`*^9}, {
   3.5827322895031767`*^9, 3.5827322910202637`*^9}, {3.582732323709133*^9, 
   3.58273234970862*^9}, {3.582732385178649*^9, 3.582732385652676*^9}, {
   3.582732425147935*^9, 3.5827324713465776`*^9}, {3.582732524904641*^9, 
   3.582732591223434*^9}, {3.5827326375450835`*^9, 3.582732697208496*^9}, {
   3.582732734273616*^9, 3.582732734658638*^9}, {3.582732783753446*^9, 
   3.5827327875226617`*^9}, {3.5827328443549123`*^9, 
   3.5827328662581654`*^9}, {3.582734707815235*^9, 3.5827347460433025`*^9}, {
   3.582734904864185*^9, 3.5827349179536076`*^9}, {3.58273495311147*^9, 
   3.5827349591808805`*^9}, {3.5827518732637014`*^9, 
   3.5827519048069572`*^9}, {3.582752271324401*^9, 3.5827522833052225`*^9}, {
   3.5827523532053456`*^9, 3.58275235571695*^9}, {3.5827524125478497`*^9, 
   3.5827524126882505`*^9}, {3.582752597876176*^9, 3.5827526058789897`*^9}, {
   3.5827526971859503`*^9, 3.582752697685151*^9}, 3.582752801440933*^9, {
   3.5827528332337885`*^9, 3.582752917661137*^9}, {3.5827529553508034`*^9, 
   3.582753154953154*^9}, {3.582753416409613*^9, 3.582753461244092*^9}, {
   3.582753655853235*^9, 3.582753940850135*^9}, {3.5827539832042093`*^9, 
   3.5827539905518227`*^9}, {3.582754032032295*^9, 3.5827545472232003`*^9}, {
   3.5827545967844872`*^9, 3.582754599358492*^9}, {3.5827546556433907`*^9, 
   3.5827548487093296`*^9}, {3.5828033949590225`*^9, 
   3.5828034500661745`*^9}, {3.582803547748761*^9, 3.582803554997176*^9}, {
   3.582803602830912*^9, 3.582803628392374*^9}, {3.582803661854288*^9, 
   3.5828036672185946`*^9}, {3.582803713687252*^9, 3.582803714530301*^9}, {
   3.5828037903536377`*^9, 3.582803837216318*^9}, {3.582803883391959*^9, 
   3.5828038843210125`*^9}, {3.582803990729869*^9, 3.582804062039796*^9}, {
   3.582804133049521*^9, 3.582804147777947*^9}, {3.5828041888100195`*^9, 
   3.5828041902920218`*^9}, {3.5828044850405445`*^9, 
   3.5828044869603477`*^9}, {3.5828046883357043`*^9, 3.582804689272706*^9}, {
   3.582804730589579*^9, 3.582804731712781*^9}, {3.582804857487603*^9, 
   3.5828048789104414`*^9}, {3.5828049293835306`*^9, 
   3.5828051094282484`*^9}, {3.5828051731759605`*^9, 
   3.5828051846751814`*^9}, {3.5828064158121586`*^9, 
   3.5828064168322167`*^9}, {3.582806555199131*^9, 3.58280655536314*^9}, {
   3.5828080723619075`*^9, 3.5828080725959206`*^9}, {3.58280814774922*^9, 
   3.5828081481002398`*^9}, 3.5828083194450397`*^9, 3.58280837504722*^9, {
   3.582808537479511*^9, 3.582808551035286*^9}, {3.582893496188904*^9, 
   3.5828938055062475`*^9}, {3.582893894286003*^9, 3.5828939103540316`*^9}, {
   3.5828990661838894`*^9, 3.582899160613361*^9}, {3.5828991984869366`*^9, 
   3.582899480740934*^9}, {3.5828999935370407`*^9, 3.582900102206832*^9}, {
   3.5829001816109715`*^9, 3.58290041915779*^9}, 3.582900492587119*^9, {
   3.5829005254989786`*^9, 3.582900576233675*^9}, {3.5829006780578566`*^9, 
   3.582900687464673*^9}, {3.582900726776742*^9, 3.5829007269795427`*^9}, {
   3.5829007572435956`*^9, 3.582900787039648*^9}, {3.5829008175221014`*^9, 
   3.5829008181149025`*^9}, {3.5829008573333716`*^9, 
   3.5829008709833956`*^9}, {3.5829009081738605`*^9, 
   3.5829009830019956`*^9}, {3.58290103109688*^9, 3.582901085010575*^9}, {
   3.582901540845605*^9, 3.5829015725292606`*^9}, {3.5829017132334075`*^9, 
   3.5829017134050083`*^9}, {3.582901789270441*^9, 3.5829017915193453`*^9}, {
   3.5829018462623415`*^9, 3.582901863500372*^9}, {3.5829019178845673`*^9, 
   3.582901950582225*^9}, {3.582902017069542*^9, 3.582902024635555*^9}, {
   3.582902078268449*^9, 3.5829020783932495`*^9}, {3.5829021144761124`*^9, 
   3.5829021814929333`*^9}, {3.5829022220530043`*^9, 3.582902229460218*^9}, {
   3.582902637208134*^9, 3.5829026828276143`*^9}, {3.582902790078105*^9, 
   3.5829028141720476`*^9}, {3.5829029118226194`*^9, 
   3.5829029146930246`*^9}, {3.5829029579076004`*^9, 
   3.5829029670698166`*^9}, {3.5829030023882785`*^9, 3.58290300889349*^9}, {
   3.5829030615435824`*^9, 3.5829030718240004`*^9}, {3.5829031138735743`*^9, 
   3.5829031238901935`*^9}, 3.5832643962542243`*^9, {3.5832676329915123`*^9, 
   3.583267744281246*^9}, {3.5832677791724815`*^9, 3.5832678759356155`*^9}, {
   3.583268061655322*^9, 3.583268121878694*^9}, {3.583268152327381*^9, 
   3.5832681738445234`*^9}, {3.5832682318819146`*^9, 
   3.5832682398304653`*^9}, {3.5832682707406607`*^9, 3.583268275801692*^9}, {
   3.583268321018978*^9, 3.583268323409993*^9}, {3.583268365330271*^9, 
   3.583268366037775*^9}, {3.583268510312234*^9, 3.5832685549310403`*^9}, {
   3.5832685871507664`*^9, 3.5832685886507773`*^9}, {3.5832686359851055`*^9, 
   3.5832686432776546`*^9}, {3.5832686804389167`*^9, 3.583268691621497*^9}, {
   3.5832687361503024`*^9, 3.5832687373253098`*^9}, {3.583268780071597*^9, 
   3.5832687861966343`*^9}, {3.583271234408679*^9, 3.583271409061834*^9}, {
   3.583271454305642*^9, 3.5832714863393493`*^9}, {3.5832715626123724`*^9, 
   3.5832715791499863`*^9}, {3.5832717414390926`*^9, 
   3.5832718104475765`*^9}, {3.5832722171468945`*^9, 3.583272217379396*^9}, {
   3.5832722823908234`*^9, 3.5832722825333242`*^9}, {3.583272388066034*^9, 
   3.583272388416037*^9}, {3.583272485167198*^9, 3.583272515348411*^9}, 
   3.5995940585680113`*^9, {3.5995940940930433`*^9, 3.599594095314113*^9}, {
   3.5995941821140776`*^9, 3.5995942030322742`*^9}, {3.5995942639277573`*^9, 
   3.599594264282778*^9}, 3.6003825485407267`*^9, 3.6003826306984262`*^9, {
   3.6003858878867264`*^9, 3.600385950330298*^9}, {3.600389958612559*^9, 
   3.6003899619577503`*^9}, {3.600390095988416*^9, 3.6003901386158543`*^9}, {
   3.6003902078308134`*^9, 3.600390294693782*^9}, {3.6003903491068935`*^9, 
   3.6003903535111456`*^9}, {3.600390473559012*^9, 3.600390525324973*^9}, {
   3.6003905892716303`*^9, 3.6003906143550653`*^9}, {3.600390691251463*^9, 
   3.6003907078104105`*^9}, {3.600390848963484*^9, 3.600390854210784*^9}, {
   3.6003909858883157`*^9, 3.6003909878094254`*^9}, 3.6003910281737337`*^9, 
   3.6003910630987315`*^9, 3.6003912203817277`*^9, {3.6003913268908195`*^9, 
   3.6003913362313538`*^9}, {3.600391407402425*^9, 3.6003914270645494`*^9}, {
   3.600391937128723*^9, 3.600392023190646*^9}, {3.6003921896851687`*^9, 
   3.6003921903892093`*^9}, {3.600392997940398*^9, 3.600393006866909*^9}, {
   3.600393329488362*^9, 3.6003933492324915`*^9}, {3.600393465887163*^9, 
   3.6003934925756903`*^9}, {3.600393589389227*^9, 3.6003935959646034`*^9}, 
   3.600393694349231*^9, {3.600393884858127*^9, 3.6003939155958853`*^9}, {
   3.6003940510966353`*^9, 3.600394053114751*^9}, {3.6003941155123196`*^9, 
   3.600394123134756*^9}, {3.600394227083701*^9, 3.600394227511726*^9}, {
   3.600394278424638*^9, 3.6003942828258896`*^9}, {3.600394654056123*^9, 
   3.6003946576193266`*^9}, 3.6003947245661554`*^9, {3.6003947780192127`*^9, 
   3.600394829123136*^9}, 3.60039486224203*^9, {3.6003949581315145`*^9, 
   3.6003949866291447`*^9}, {3.6003950818565917`*^9, 3.600395108214099*^9}, {
   3.6003951885606947`*^9, 3.60039528901044*^9}, {3.6003957309587183`*^9, 
   3.6003957408552837`*^9}, {3.6003958605271287`*^9, 3.60039586211022*^9}, {
   3.600395940362695*^9, 3.6003959450509634`*^9}, {3.6003960773555307`*^9, 
   3.60039612279313*^9}, {3.6003961611993265`*^9, 3.600396247789279*^9}, {
   3.6003963485390415`*^9, 3.6003964070963907`*^9}, {3.6003965108903275`*^9, 
   3.600396537878871*^9}, {3.60039674957298*^9, 3.6003967499920034`*^9}, {
   3.600396790506321*^9, 3.6003967912723646`*^9}, {3.6003968282484794`*^9, 
   3.6003968422462797`*^9}, {3.6003968841836786`*^9, 3.600396891427093*^9}, {
   3.600396941061932*^9, 3.6003969503894653`*^9}, {3.6003970035425053`*^9, 
   3.6003970073017206`*^9}, {3.6003971196531467`*^9, 3.600397166835846*^9}, {
   3.600397198993685*^9, 3.60039724156912*^9}, {3.6003972724218845`*^9, 
   3.600397325090897*^9}, {3.600397398354088*^9, 3.600397403103359*^9}, {
   3.600397451808145*^9, 3.600397495221628*^9}, {3.600397536672999*^9, 
   3.6003975637455473`*^9}, {3.60039762270492*^9, 3.600397674495882*^9}, {
   3.6003977098739057`*^9, 3.6003977115650024`*^9}, {3.6003977427187843`*^9, 
   3.6003977718694515`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FindRoot", "::", "lstol"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"The line search decreased the step size to within \
tolerance specified by AccuracyGoal and PrecisionGoal but was unable to find \
a sufficient decrease in the merit function. You may need more than \
\[NoBreak]\\!\\(MachinePrecision\\)\[NoBreak] digits of working precision to \
meet these tolerances. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/FindRoot/lstol\\\", ButtonNote -> \
\\\"FindRoot::lstol\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{{3.600397743890851*^9, 3.600397772867509*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FindRoot", "::", "lstol"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"The line search decreased the step size to within \
tolerance specified by AccuracyGoal and PrecisionGoal but was unable to find \
a sufficient decrease in the merit function. You may need more than \
\[NoBreak]\\!\\(MachinePrecision\\)\[NoBreak] digits of working precision to \
meet these tolerances. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/FindRoot/lstol\\\", ButtonNote -> \
\\\"FindRoot::lstol\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{{3.600397743890851*^9, 3.6003977730095167`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FindRoot", "::", "lstol"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"The line search decreased the step size to within \
tolerance specified by AccuracyGoal and PrecisionGoal but was unable to find \
a sufficient decrease in the merit function. You may need more than \
\[NoBreak]\\!\\(MachinePrecision\\)\[NoBreak] digits of working precision to \
meet these tolerances. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/FindRoot/lstol\\\", ButtonNote -> \
\\\"FindRoot::lstol\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{{3.600397743890851*^9, 3.6003977731425247`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \[NoBreak]\\!\\(\\*StyleBox[\\(FindRoot \
:: lstol\\), \\\"MessageName\\\"]\\)\[NoBreak] will be suppressed during this \
calculation. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/stop\\\", ButtonNote -> \
\\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{{3.600397743890851*^9, 3.6003977731585255`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"c=\"\>", "\[InvisibleSpace]", "0.1`"}],
  SequenceForm["c=", 0.1],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.6003975666157117`*^9, {3.600397653604687*^9, 3.6003976765129976`*^9}, 
   3.600397713691124*^9, 3.6003977469240246`*^9, 3.600397782232044*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Total power: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "2.903663852635508`", ",", "2.914398887040026`", ",", 
     "2.925596963528573`", ",", "2.937210659485661`", ",", 
     "2.9492287813455738`", ",", "2.961642390784533`", ",", 
     "2.974445601988166`", ",", "2.987621279474796`", ",", 
     "3.001159829627785`", ",", "3.0150540570914384`", ",", 
     "3.0292883866158857`", ",", "3.0438537876804816`", ",", 
     "3.0587380511585374`", ",", "3.0739283286759567`", ",", 
     "3.0894159340102334`", ",", "3.1051888654241306`", ",", 
     "3.121235247543503`", ",", "3.137545810160198`", ",", 
     "3.154110276191114`", ",", "3.170916201348511`"}], "}"}]}],
  SequenceForm[
  "Total power: ", {2.903663852635508, 2.914398887040026, 2.925596963528573, 
   2.937210659485661, 2.9492287813455738`, 2.961642390784533, 
   2.974445601988166, 2.987621279474796, 3.001159829627785, 
   3.0150540570914384`, 3.0292883866158857`, 3.0438537876804816`, 
   3.0587380511585374`, 3.0739283286759567`, 3.0894159340102334`, 
   3.1051888654241306`, 3.121235247543503, 3.137545810160198, 
   3.154110276191114, 3.170916201348511}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.6003975666157117`*^9, {3.600397653604687*^9, 3.6003976765129976`*^9}, 
   3.600397713691124*^9, 3.6003977469240246`*^9, 3.600397782233044*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Total incoming: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "146400", ",", "148800", ",", "151200", ",", "153600", ",", "156000", ",",
      "158400", ",", "160800", ",", "163200", ",", "165600", ",", "168000", 
     ",", "170400", ",", "172800", ",", "175200", ",", "177600", ",", 
     "180000", ",", "182400", ",", "184800", ",", "187200", ",", "189600", 
     ",", "192000"}], "}"}]}],
  SequenceForm[
  "Total incoming: ", {146400, 148800, 151200, 153600, 156000, 158400, 160800,
    163200, 165600, 168000, 170400, 172800, 175200, 177600, 180000, 182400, 
   184800, 187200, 189600, 192000}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.6003975666157117`*^9, {3.600397653604687*^9, 3.6003976765129976`*^9}, 
   3.600397713691124*^9, 3.6003977469240246`*^9, 3.600397782234044*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Total outgoing: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "178419.48992083367`", ",", "178670.8205798778`", ",", 
     "178928.02032288525`", ",", "179189.71979652863`", ",", 
     "179455.41004059697`", ",", "179724.652387552`", ",", 
     "179997.09274797502`", ",", "180272.14651761972`", ",", 
     "180549.41432499373`", ",", "180828.56358809414`", ",", 
     "181109.09841294523`", ",", "181390.67933211563`", ",", 
     "181672.91531754239`", ",", "181955.4187896134`", ",", 
     "182237.90237242403`", ",", "182520.02528345134`", ",", 
     "182801.46492863272`", ",", "183081.96416720765`", ",", 
     "183361.2584055729`", ",", "183639.0560252217`"}], "}"}]}],
  SequenceForm[
  "Total outgoing: ", {178419.48992083367`, 178670.8205798778, 
   178928.02032288525`, 179189.71979652863`, 179455.41004059697`, 
   179724.652387552, 179997.09274797502`, 180272.14651761972`, 
   180549.41432499373`, 180828.56358809414`, 181109.09841294523`, 
   181390.67933211563`, 181672.91531754239`, 181955.4187896134, 
   182237.90237242403`, 182520.02528345134`, 182801.46492863272`, 
   183081.96416720765`, 183361.2584055729, 183639.0560252217}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.6003975666157117`*^9, {3.600397653604687*^9, 3.6003976765129976`*^9}, 
   3.600397713691124*^9, 3.6003977469240246`*^9, 3.6003977822350445`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reliability: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1",
      ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", 
     ",", "1", ",", "0.9891854162804801`", ",", "0.9780019453376477`", ",", 
     "0.9670952447551313`", ",", "0.9564534167980298`"}], "}"}]}],
  SequenceForm[
  "Reliability: ", {
   1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0.9891854162804801, 
    0.9780019453376477, 0.9670952447551313, 0.9564534167980298}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.6003975666157117`*^9, {3.600397653604687*^9, 3.6003976765129976`*^9}, 
   3.600397713691124*^9, 3.6003977469240246`*^9, 3.6003977822360444`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"c=\"\>", "\[InvisibleSpace]", "0.15`"}],
  SequenceForm["c=", 0.15],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.6003975666157117`*^9, {3.600397653604687*^9, 3.6003976765129976`*^9}, 
   3.600397713691124*^9, 3.6003977469240246`*^9, 3.600397791217558*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Total power: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "3.0849164169318106`", ",", "3.1041373844194204`", ",", 
     "3.1238063290465976`", ",", "3.1438667342423603`", ",", 
     "3.16430189743608`", ",", "3.1850944111270607`", ",", 
     "3.206225408082886`", ",", "3.227680512165696`", ",", 
     "3.2494404364449605`", ",", "3.2714935849951674`", ",", 
     "3.2938231467894643`", ",", "3.3164217386616173`", ",", 
     "3.3392696699252253`", ",", "3.362357972835101`", ",", 
     "3.3856740669259224`", ",", "3.4092101920711277`", ",", 
     "3.4329517032333565`", ",", "3.456893024105037`", ",", 
     "3.481023787137046`", ",", "3.505337783013001`"}], "}"}]}],
  SequenceForm[
  "Total power: ", {3.0849164169318106`, 3.1041373844194204`, 
   3.1238063290465976`, 3.1438667342423603`, 3.16430189743608, 
   3.1850944111270607`, 3.206225408082886, 3.227680512165696, 
   3.2494404364449605`, 3.2714935849951674`, 3.2938231467894643`, 
   3.3164217386616173`, 3.3392696699252253`, 3.362357972835101, 
   3.3856740669259224`, 3.4092101920711277`, 3.4329517032333565`, 
   3.456893024105037, 3.481023787137046, 3.505337783013001}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.6003975666157117`*^9, {3.600397653604687*^9, 3.6003976765129976`*^9}, 
   3.600397713691124*^9, 3.6003977469240246`*^9, 3.6003977912185583`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Total incoming: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "146400", ",", "148800", ",", "151200", ",", "153600", ",", "156000", ",",
      "158400", ",", "160800", ",", "163200", ",", "165600", ",", "168000", 
     ",", "170400", ",", "172800", ",", "175200", ",", "177600", ",", 
     "180000", ",", "182400", ",", "184800", ",", "187200", ",", "189600", 
     ",", "192000"}], "}"}]}],
  SequenceForm[
  "Total incoming: ", {146400, 148800, 151200, 153600, 156000, 158400, 160800,
    163200, 165600, 168000, 170400, 172800, 175200, 177600, 180000, 182400, 
   184800, 187200, 189600, 192000}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.6003975666157117`*^9, {3.600397653604687*^9, 3.6003976765129976`*^9}, 
   3.600397713691124*^9, 3.6003977469240246`*^9, 3.6003977912195582`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Total outgoing: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "182156.45674060466`", ",", "182501.37953700038`", ",", 
     "182846.04200823238`", ",", "183189.1841839247`", ",", 
     "183530.37023296597`", ",", "183869.17743354698`", ",", 
     "184205.18306766293`", ",", "184538.0724752788`", ",", 
     "184867.46718567616`", ",", "185193.1465353287`", ",", 
     "185514.82028683514`", ",", "185832.37459279347`", ",", 
     "186145.50922921073`", ",", "186454.1175999316`", ",", 
     "186758.0483914003`", ",", "187057.23869709935`", ",", 
     "187351.53274322837`", ",", "187640.9221341527`", ",", 
     "187925.3364352546`", ",", "188204.77286759776`"}], "}"}]}],
  SequenceForm[
  "Total outgoing: ", {182156.45674060466`, 182501.37953700038`, 
   182846.04200823238`, 183189.1841839247, 183530.37023296597`, 
   183869.17743354698`, 184205.18306766293`, 184538.0724752788, 
   184867.46718567616`, 185193.1465353287, 185514.82028683514`, 
   185832.37459279347`, 186145.50922921073`, 186454.1175999316, 
   186758.0483914003, 187057.23869709935`, 187351.53274322837`, 
   187640.9221341527, 187925.3364352546, 188204.77286759776`}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.6003975666157117`*^9, {3.600397653604687*^9, 3.6003976765129976`*^9}, 
   3.600397713691124*^9, 3.6003977469240246`*^9, 3.600397791220558*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reliability: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1",
      ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", 
     ",", "1", ",", "1", ",", "1", ",", "0.9911673862618914`", ",", 
     "0.9802331920187383`"}], "}"}]}],
  SequenceForm[
  "Reliability: ", {
   1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0.9911673862618914, 
    0.9802331920187383}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.6003975666157117`*^9, {3.600397653604687*^9, 3.6003976765129976`*^9}, 
   3.600397713691124*^9, 3.6003977469240246`*^9, 3.6003977912215586`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"c=\"\>", "\[InvisibleSpace]", "0.2`"}],
  SequenceForm["c=", 0.2],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.6003975666157117`*^9, {3.600397653604687*^9, 3.6003976765129976`*^9}, 
   3.600397713691124*^9, 3.6003977469240246`*^9, 3.6003978018261647`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Total power: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "3.2812404945393907`", ",", "3.3071549465063024`", ",", 
     "3.3334420807875063`", ",", "3.360052401800905`", ",", 
     "3.386973591076413`", ",", "3.4141817755278034`", ",", 
     "3.4416631340315162`", ",", "3.469430777180111`", ",", 
     "3.4974200867987224`", ",", "3.525644946685926`", ",", 
     "3.554094205109183`", ",", "3.5827521197168135`", ",", 
     "3.6116153240994713`", ",", "3.6406683459724603`", ",", 
     "3.6699067656899262`", ",", "3.699320074723227`", ",", 
     "3.7289026457754515`", ",", "3.758644432335023`", ",", 
     "3.788540711867433`", ",", "3.8185865715542997`"}], "}"}]}],
  SequenceForm[
  "Total power: ", {3.2812404945393907`, 3.3071549465063024`, 
   3.3334420807875063`, 3.360052401800905, 3.386973591076413, 
   3.4141817755278034`, 3.4416631340315162`, 3.469430777180111, 
   3.4974200867987224`, 3.525644946685926, 3.554094205109183, 
   3.5827521197168135`, 3.6116153240994713`, 3.6406683459724603`, 
   3.6699067656899262`, 3.699320074723227, 3.7289026457754515`, 
   3.758644432335023, 3.788540711867433, 3.8185865715542997`}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.6003975666157117`*^9, {3.600397653604687*^9, 3.6003976765129976`*^9}, 
   3.600397713691124*^9, 3.6003977469240246`*^9, 3.6003978018271646`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Total incoming: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "146400", ",", "148800", ",", "151200", ",", "153600", ",", "156000", ",",
      "158400", ",", "160800", ",", "163200", ",", "165600", ",", "168000", 
     ",", "170400", ",", "172800", ",", "175200", ",", "177600", ",", 
     "180000", ",", "182400", ",", "184800", ",", "187200", ",", "189600", 
     ",", "192000"}], "}"}]}],
  SequenceForm[
  "Total incoming: ", {146400, 148800, 151200, 153600, 156000, 158400, 160800,
    163200, 165600, 168000, 170400, 172800, 175200, 177600, 180000, 182400, 
   184800, 187200, 189600, 192000}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.6003975666157117`*^9, {3.600397653604687*^9, 3.6003976765129976`*^9}, 
   3.600397713691124*^9, 3.6003977469240246`*^9, 3.600397801828165*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Total outgoing: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "185334.609681211`", ",", "185703.10877792572`", ",", 
     "186066.3729858364`", ",", "186423.63263832085`", ",", 
     "186774.76046246977`", ",", "187119.473859168`", ",", 
     "187457.6697723658`", ",", "187789.64462391817`", ",", 
     "188114.59716083173`", ",", "188432.87283520098`", ",", 
     "188744.46411068196`", ",", "189049.3150649233`", ",", 
     "189347.540632173`", ",", "189639.10743739337`", ",", 
     "189924.12786418517`", ",", "190202.64388187102`", ",", 
     "190474.75973337618`", ",", "190740.5317973874`", ",", 
     "191000.07971120166`", ",", "191253.52031213653`"}], "}"}]}],
  SequenceForm[
  "Total outgoing: ", {185334.609681211, 185703.10877792572`, 
   186066.3729858364, 186423.63263832085`, 186774.76046246977`, 
   187119.473859168, 187457.6697723658, 187789.64462391817`, 
   188114.59716083173`, 188432.87283520098`, 188744.46411068196`, 
   189049.3150649233, 189347.540632173, 189639.10743739337`, 
   189924.12786418517`, 190202.64388187102`, 190474.75973337618`, 
   190740.5317973874, 191000.07971120166`, 191253.52031213653`}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.6003975666157117`*^9, {3.600397653604687*^9, 3.6003976765129976`*^9}, 
   3.600397713691124*^9, 3.6003977469240246`*^9, 3.6003978018291655`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reliability: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1",
      ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", 
     ",", "1", ",", "1", ",", "1", ",", "1", ",", "0.9961120849590445`"}], 
    "}"}]}],
  SequenceForm[
  "Reliability: ", {
   1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
    0.9961120849590445}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.6003975666157117`*^9, {3.600397653604687*^9, 3.6003976765129976`*^9}, 
   3.600397713691124*^9, 3.6003977469240246`*^9, 3.600397801830165*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"c=\"\>", "\[InvisibleSpace]", "0.25`"}],
  SequenceForm["c=", 0.25],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.6003975666157117`*^9, {3.600397653604687*^9, 3.6003976765129976`*^9}, 
   3.600397713691124*^9, 3.6003977469240246`*^9, 3.600397813190815*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Total power: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "3.4750232246419643`", ",", "3.5063717129618346`", ",", 
     "3.538025589657531`", ",", "3.5699495668605388`", ",", 
     "3.6021332534712585`", ",", "3.634559081360341`", ",", 
     "3.6672171404089777`", ",", "3.7000964925040516`", ",", 
     "3.733186053716204`", ",", "3.7664735964421077`", ",", 
     "3.79995437201144`", ",", "3.8336148307005082`", ",", 
     "3.867453168552716`", ",", "3.9014581677501017`", ",", 
     "3.9356232081846505`", ",", "3.9699432644279264`", ",", 
     "4.004412012327702`", ",", "4.039022330063755`", ",", 
     "4.073776175487067`", ",", "4.108660329384438`"}], "}"}]}],
  SequenceForm[
  "Total power: ", {3.4750232246419643`, 3.5063717129618346`, 
   3.538025589657531, 3.5699495668605388`, 3.6021332534712585`, 
   3.634559081360341, 3.6672171404089777`, 3.7000964925040516`, 
   3.733186053716204, 3.7664735964421077`, 3.79995437201144, 
   3.8336148307005082`, 3.867453168552716, 3.9014581677501017`, 
   3.9356232081846505`, 3.9699432644279264`, 4.004412012327702, 
   4.039022330063755, 4.073776175487067, 4.108660329384438}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.6003975666157117`*^9, {3.600397653604687*^9, 3.6003976765129976`*^9}, 
   3.600397713691124*^9, 3.6003977469240246`*^9, 3.600397813193815*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Total incoming: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "146400", ",", "148800", ",", "151200", ",", "153600", ",", "156000", ",",
      "158400", ",", "160800", ",", "163200", ",", "165600", ",", "168000", 
     ",", "170400", ",", "172800", ",", "175200", ",", "177600", ",", 
     "180000", ",", "182400", ",", "184800", ",", "187200", ",", "189600", 
     ",", "192000"}], "}"}]}],
  SequenceForm[
  "Total incoming: ", {146400, 148800, 151200, 153600, 156000, 158400, 160800,
    163200, 165600, 168000, 170400, 172800, 175200, 177600, 180000, 182400, 
   184800, 187200, 189600, 192000}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.6003975666157117`*^9, {3.600397653604687*^9, 3.6003976765129976`*^9}, 
   3.600397713691124*^9, 3.6003977469240246`*^9, 3.600397813194815*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Total outgoing: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "187855.36083764717`", ",", "188216.54173799936`", ",", 
     "188569.5884639879`", ",", "188914.22271399986`", ",", 
     "189250.52597255228`", ",", "189578.4994708642`", ",", 
     "189898.25235348608`", ",", "190209.8875048477`", ",", 
     "190513.51203525314`", ",", "190809.22654767806`", ",", 
     "191097.21784797465`", ",", "191377.57853214728`", ",", 
     "191650.5264035256`", ",", "191916.18077172432`", ",", 
     "192174.70834147878`", ",", "192426.28844772768`", ",", 
     "192671.08601322648`", ",", "192909.25633803304`", ",", 
     "193141.03064171673`", ",", "193366.50469192414`"}], "}"}]}],
  SequenceForm[
  "Total outgoing: ", {187855.36083764717`, 188216.54173799936`, 
   188569.5884639879, 188914.22271399986`, 189250.52597255228`, 
   189578.4994708642, 189898.25235348608`, 190209.8875048477, 
   190513.51203525314`, 190809.22654767806`, 191097.21784797465`, 
   191377.57853214728`, 191650.5264035256, 191916.18077172432`, 
   192174.70834147878`, 192426.28844772768`, 192671.08601322648`, 
   192909.25633803304`, 193141.03064171673`, 193366.50469192414`}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.6003975666157117`*^9, {3.600397653604687*^9, 3.6003976765129976`*^9}, 
   3.600397713691124*^9, 3.6003977469240246`*^9, 3.600397813195815*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reliability: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1",
      ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", 
     ",", "1", ",", "1", ",", "1", ",", "1", ",", "1"}], "}"}]}],
  SequenceForm[
  "Reliability: ", {1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
   1}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.6003975666157117`*^9, {3.600397653604687*^9, 3.6003976765129976`*^9}, 
   3.600397713691124*^9, 3.6003977469240246`*^9, 3.6003978131968155`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"c=\"\>", "\[InvisibleSpace]", "0.3`"}],
  SequenceForm["c=", 0.3],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.6003975666157117`*^9, {3.600397653604687*^9, 3.6003976765129976`*^9}, 
   3.600397713691124*^9, 3.6003977469240246`*^9, 3.60039782464447*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Total power: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "3.661408350034029`", ",", "3.6973778261402495`", ",", 
     "3.733616774954338`", ",", "3.7700964792779796`", ",", 
     "3.8068049342142`", ",", "3.8437261246048307`", ",", 
     "3.8808594594247574`", ",", "3.918186704737949`", ",", 
     "3.9557054689198727`", ",", "3.993405104791415`", ",", 
     "4.031277171370936`", ",", "4.069319521787845`", ",", 
     "4.107521645888941`", ",", "4.145880252059686`", ",", 
     "4.184390494816539`", ",", "4.223048872494752`", ",", 
     "4.261844147211515`", ",", "4.300779907184183`", ",", 
     "4.339857392440585`", ",", "4.379057674701259`"}], "}"}]}],
  SequenceForm[
  "Total power: ", {3.661408350034029, 3.6973778261402495`, 3.733616774954338,
    3.7700964792779796`, 3.8068049342142, 3.8437261246048307`, 
   3.8808594594247574`, 3.918186704737949, 3.9557054689198727`, 
   3.993405104791415, 4.031277171370936, 4.069319521787845, 4.107521645888941,
    4.145880252059686, 4.184390494816539, 4.223048872494752, 
   4.261844147211515, 4.300779907184183, 4.339857392440585, 
   4.379057674701259}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.6003975666157117`*^9, {3.600397653604687*^9, 3.6003976765129976`*^9}, 
   3.600397713691124*^9, 3.6003977469240246`*^9, 3.6003978246474705`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Total incoming: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "146400", ",", "148800", ",", "151200", ",", "153600", ",", "156000", ",",
      "158400", ",", "160800", ",", "163200", ",", "165600", ",", "168000", 
     ",", "170400", ",", "172800", ",", "175200", ",", "177600", ",", 
     "180000", ",", "182400", ",", "184800", ",", "187200", ",", "189600", 
     ",", "192000"}], "}"}]}],
  SequenceForm[
  "Total incoming: ", {146400, 148800, 151200, 153600, 156000, 158400, 160800,
    163200, 165600, 168000, 170400, 172800, 175200, 177600, 180000, 182400, 
   184800, 187200, 189600, 192000}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.6003975666157117`*^9, {3.600397653604687*^9, 3.6003976765129976`*^9}, 
   3.600397713691124*^9, 3.6003977469240246`*^9, 3.6003978246484704`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Total outgoing: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "189842.17158696405`", ",", "190184.49808907672`", ",", 
     "190517.39505730954`", ",", "190840.83915000487`", ",", 
     "191155.01134726853`", ",", "191460.05486029858`", ",", 
     "191756.27365171612`", ",", "192043.79051551808`", ",", 
     "192322.88460058108`", ",", "192593.75128925382`", ",", 
     "192856.60458870803`", ",", "193111.7088983512`", ",", 
     "193359.25045007782`", ",", "193599.47188373836`", ",", 
     "193832.59571863594`", ",", "194058.84830119257`", ",", 
     "194278.39214226566`", ",", "194491.49350334395`", ",", 
     "194698.38952840376`", ",", "194899.1731382886`"}], "}"}]}],
  SequenceForm[
  "Total outgoing: ", {189842.17158696405`, 190184.49808907672`, 
   190517.39505730954`, 190840.83915000487`, 191155.01134726853`, 
   191460.05486029858`, 191756.27365171612`, 192043.79051551808`, 
   192322.88460058108`, 192593.75128925382`, 192856.60458870803`, 
   193111.7088983512, 193359.25045007782`, 193599.47188373836`, 
   193832.59571863594`, 194058.84830119257`, 194278.39214226566`, 
   194491.49350334395`, 194698.38952840376`, 194899.1731382886}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.6003975666157117`*^9, {3.600397653604687*^9, 3.6003976765129976`*^9}, 
   3.600397713691124*^9, 3.6003977469240246`*^9, 3.6003978246494703`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reliability: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1",
      ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", 
     ",", "1", ",", "1", ",", "1", ",", "1", ",", "1"}], "}"}]}],
  SequenceForm[
  "Reliability: ", {1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
   1}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.6003975666157117`*^9, {3.600397653604687*^9, 3.6003976765129976`*^9}, 
   3.600397713691124*^9, 3.6003977469240246`*^9, 3.6003978246504707`*^9}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{944, 1002},
WindowMargins->{{Automatic, 0}, {0, Automatic}},
FrontEndVersion->"9.0 for Microsoft Windows (64-bit) (January 25, 2013)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 77709, 1735, 8612, "Input"],
Cell[78291, 1759, 712, 13, 56, "Message"],
Cell[79006, 1774, 714, 13, 56, "Message"],
Cell[79723, 1789, 714, 13, 56, "Message"],
Cell[80440, 1804, 558, 11, 21, "Message"],
Cell[CellGroupData[{
Cell[81023, 1819, 312, 7, 23, "Print"],
Cell[81338, 1828, 1387, 26, 43, "Print"],
Cell[82728, 1856, 863, 17, 43, "Print"],
Cell[83594, 1875, 1414, 26, 43, "Print"],
Cell[85011, 1903, 794, 16, 23, "Print"],
Cell[85808, 1921, 314, 7, 23, "Print"],
Cell[86125, 1930, 1402, 26, 43, "Print"],
Cell[87530, 1958, 865, 17, 43, "Print"],
Cell[88398, 1977, 1408, 26, 43, "Print"],
Cell[89809, 2005, 724, 16, 23, "Print"],
Cell[90536, 2023, 314, 7, 23, "Print"],
Cell[90853, 2032, 1401, 26, 43, "Print"],
Cell[92257, 2060, 863, 17, 43, "Print"],
Cell[93123, 2079, 1404, 26, 43, "Print"],
Cell[94530, 2107, 686, 16, 23, "Print"],
Cell[95219, 2125, 314, 7, 23, "Print"],
Cell[95536, 2134, 1394, 26, 43, "Print"],
Cell[96933, 2162, 863, 17, 43, "Print"],
Cell[97799, 2181, 1417, 26, 43, "Print"],
Cell[99219, 2209, 643, 14, 23, "Print"],
Cell[99865, 2225, 311, 7, 23, "Print"],
Cell[100179, 2234, 1376, 26, 43, "Print"],
Cell[101558, 2262, 865, 17, 43, "Print"],
Cell[102426, 2281, 1425, 26, 43, "Print"],
Cell[103854, 2309, 643, 14, 23, "Print"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
